==> juju-core_2.0.2.orig.tar.gz: juju-core_2.0.2/src/github.com/juju/juju/cmd/juju/application/constraints_test.go <==
// Copyright 2015 Canonical Ltd.
// Licensed under the AGPLv3, see LICENCE file for details.

package application_test

import (
	jc "github.com/juju/testing/checkers"
	gc "gopkg.in/check.v1"

	"github.com/juju/juju/cmd/juju/application"
	"github.com/juju/juju/testing"
)

type ServiceConstraintsCommandsSuite struct {
	testing.FakeJujuXDGDataHomeSuite
}

var _ = gc.Suite(&ServiceConstraintsCommandsSuite{})

func (s *ServiceConstraintsCommandsSuite) TestSetInit(c *gc.C) {
	for _, test := range []struct {
		args []string
		err  string
	}{
		{
			args: []string{"--application", "mysql", "mem=4G"},
			err:  `flag provided but not defined: --application`,
		}, {
			args: []string{"-s", "mysql", "mem=4G"},
			err:  `flag provided but not defined: -s`,
		}, {
			args: []string{},
			err:  `no application name specified`,
		}, {
			args: []string{"mysql", "="},
			err:  `malformed constraint "="`,
		}, {
			args: []string{"cpu-power=250"},
			err:  `invalid application name "cpu-power=250"`,
		}, {
			args: []string{"mysql", "cpu-power=250"},
		},
	} {
		err := testing.InitCommand(application.NewServiceSetConstraintsCommand(), test.args)
		if test.err == "" {
			c.Check(err, jc.ErrorIsNil)
		} else {
			c.Check(err, gc.ErrorMatches, test.err)
		}
	}
}

func (s *ServiceConstraintsCommandsSuite) TestGetInit(c *gc.C) {
	for _, test := range []struct {
		args []string
		err  string
	}{
		{
			args: []string{"-s", "mysql"},
			err:  `flag provided but not defined: -s`,
		}, {
			args: []string{"--application", "mysql"},
			err:  `flag provided but not defined: --application`,
		}, {
			args: []string{},
			err:  `no application name specified`,
		}, {
			args: []string{"mysql-0"},
			err:  `invalid application name "mysql-0"`,
		}, {
			args: []string{"mysql"},
		},
	} {
		err := testing.InitCommand(application.NewServiceGetConstraintsCommand(), test.args)
		if test.err == "" {
			c.Check(err, jc.ErrorIsNil)
		} else {
			c.Check(err, gc.ErrorMatches, test.err)
		}
	}
}

==> juju-core_2.3.7.orig.tar.gz: juju-core_2.3.7/src/github.com/juju/juju/cmd/juju/application/constraints_test.go <==
// Copyright 2015 Canonical Ltd.
// Licensed under the AGPLv3, see LICENCE file for details.

package application_test

import (
	"github.com/juju/cmd/cmdtesting"
	jc "github.com/juju/testing/checkers"
	gc "gopkg.in/check.v1"

	"github.com/juju/juju/cmd/juju/application"
	"github.com/juju/juju/testing"
)

type ServiceConstraintsCommandsSuite struct {
	testing.FakeJujuXDGDataHomeSuite
}

var _ = gc.Suite(&ServiceConstraintsCommandsSuite{})

func (s *ServiceConstraintsCommandsSuite) TestSetInit(c *gc.C) {
	for _, test := range []struct {
		args []string
		err  string
	}{{
		args: []string{"--application", "mysql", "mem=4G"},
		err:  `flag provided but not defined: --application`,
	}, {
		args: []string{"-s", "mysql", "mem=4G"},
		err:  `flag provided but not defined: -s`,
	}, {
		args: []string{},
		err:  `no application name specified`,
	}, {
		args: []string{"mysql", "="},
		err:  `malformed constraint "="`,
	}, {
		args: []string{"cpu-power=250"},
		err:  `invalid application name "cpu-power=250"`,
	}, {
		args: []string{"mysql", "cpu-power=250"},
	}} {
		cmd := application.NewServiceSetConstraintsCommand()
		cmd.SetClientStore(application.NewMockStore())
		err := cmdtesting.InitCommand(cmd, test.args)
		if test.err == "" {
			c.Check(err, jc.ErrorIsNil)
		} else {
			c.Check(err, gc.ErrorMatches, test.err)
		}
	}
}

func (s *ServiceConstraintsCommandsSuite) TestGetInit(c *gc.C) {
	for _, test := range []struct {
		args []string
		err  string
	}{
		{
			args: []string{"-s", "mysql"},
			err:  `flag provided but not defined: -s`,
		}, {
			args: []string{"--application", "mysql"},
			err:  `flag provided but not defined: --application`,
		}, {
			args: []string{},
			err:  `no application name specified`,
		}, {
			args: []string{"mysql-0"},
			err:  `invalid application name "mysql-0"`,
		}, {
			args: []string{"mysql"},
		},
	} {
		cmd := application.NewServiceGetConstraintsCommand()
		cmd.SetClientStore(application.NewMockStore())
		err := cmdtesting.InitCommand(cmd, test.args)
		if test.err == "" {
			c.Check(err, jc.ErrorIsNil)
		} else {
			c.Check(err, gc.ErrorMatches, test.err)
		}
	}
}
